VdEmptyState class

Inheritance
Available extensions

Constructors

VdEmptyState({Key? key, String title = 'Title goes here', String description = 'Nothing more exciting happening here in terms of content, ' 'but just filling up the space to make it look representative.', Widget? icon, bool boxed = true, String? primaryActionTitle, String? secondaryActionTitle, VoidCallback? onPrimaryAction, VoidCallback? onSecondaryAction})
const

Properties

boxed bool
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
Optional icon override. Replace with VdIcon in Phase 4.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPrimaryAction VoidCallback?
final
onSecondaryAction VoidCallback?
final
primaryActionTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryActionTitle String?
final
title String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
vdSkeleton({bool isEnabled = true, double cornerRadius = VdRadius.md}) Widget

Available on Widget, provided by the VdSkeletonExtension extension

Replaces this widget with an animated shimmer placeholder.

Operators

operator ==(Object other) bool
The equality operator.
inherited