VdIcon class

Inheritance
Available extensions

Constructors

VdIcon(IconData icon, {Key? key, double? size, Color? color, String? semanticLabel})
const

Properties

color Color?
Override the icon color. Defaults to the nearest IconTheme color, then DefaultTextStyle color.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
The icon glyph to render. Use a constant from VdIcons.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Optional semantic label for accessibility.
final
size double?
Override the icon size. Defaults to VdIconSize.md (24px) or the nearest IconTheme value when null.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
vdSkeleton({bool isEnabled = true, double cornerRadius = VdRadius.md}) Widget

Available on Widget, provided by the VdSkeletonExtension extension

Replaces this widget with an animated shimmer placeholder.

Operators

operator ==(Object other) bool
The equality operator.
inherited