VdFont class abstract
Constructors
- VdFont()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bodyExtraLarge → const VdTextStyle
- Body/ExtraLarge · 24 / 36 / 0
- bodyExtraSmall → const VdTextStyle
- Body/ExtraSmall · 10 / 16 / 0
- bodyLarge → const VdTextStyle
- Body/Large · 16 / 24 / 0
- bodyMedium → const VdTextStyle
- Body/Medium · 14 / 24 / 0
- bodyMediumItalic → const VdTextStyle
- Body/MediumItalic · 14 / 24 / 0
- bodySmall → const VdTextStyle
- Body/Small · 12 / 16 / 0
- displayLarge → const VdTextStyle
- Display/Large · 60 / 72 / -1.5
- displayMedium → const VdTextStyle
- Display/Medium · 48 / 56 / -1.0
- displaySmall → const VdTextStyle
- Display/Small · 40 / 48 / -0.5
- headlineLarge → const VdTextStyle
- Headline/Large · 34 / 40 / -0.3
- headlineMedium → const VdTextStyle
- Headline/Medium · 28 / 36 / -0.3
- headlineSmall → const VdTextStyle
- Headline/Small · 24 / 32 / -0.3
- labelExtraSmall → const VdTextStyle
- Label/ExtraSmall · 10 / 16 / +0.2
- labelLarge → const VdTextStyle
- Label/Large · 16 / 24 / +0.2
- labelMedium → const VdTextStyle
- Label/Medium · 14 / 24 / +0.2
- labelSmall → const VdTextStyle
- Label/Small · 12 / 16 / +0.2
- titleLarge → const VdTextStyle
- Title/Large · 20 / 28 / 0
- titleMedium → const VdTextStyle
- Title/Medium · 16 / 24 / 0
- titleSmall → const VdTextStyle
- Title/Small · 14 / 20 / 0