VdSelectField<T extends Object> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- VdSelectField
- Available extensions
Constructors
-
VdSelectField({Key? key, required T? selection, required List<
T> options, String optionLabel(T)?, String? label, String placeholder = 'Select an option', String? helperText, bool isOptional = false, Widget? leadingIcon, VdInputState state = VdInputState.normal, ValueChanged<T?> ? onChanged}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- isOptional → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- leadingIcon → Widget?
-
Optional leading icon. Replace with VdIcon in Phase 4.
final
-
onChanged
→ ValueChanged<
T?> ? -
final
- optionLabel → String Function(T)?
-
Maps an option to its display string. Defaults to
toString().final -
options
→ List<
T> -
final
- placeholder → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → T?
-
final
- state → VdInputState
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< VdSelectField< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
vdSkeleton(
{bool isEnabled = true, double cornerRadius = VdRadius.md}) → Widget -
Available on Widget, provided by the VdSkeletonExtension extension
Replaces this widget with an animated shimmer placeholder.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited